This crate provides Image, a data structure for representing and editing raster images.
The data format of a image is a sequence of ImageCommands.
See also
- patica: Terminal based pixel art editor using this crate.
Structs
- Color
- RGBA color.
- Image
- Raster image.
- Image
Command Reader ImageCommandreader.- Image
Command Writer ImageCommandwriter.- Patch
Entry - Patch entry.
- Patch
Image Command - Patch command that is used to draw or erase pixels.
- Point
- A point in 2D space.
- Version
- Number of applied commands.
- Versioned
Image Imagewith a log of appliedImageCommands.
Enums
- Image
Command Imagecommand.